# -*- text -*-
# first non-comment line must be the short description:
Utilities library with several more or less independent components

The jpylib package is meant to be a library of things I want to have at hand for my own daily python programming. It shall include all the things I have developed and want to re-use -- modules, small utility functions, and things. These are more or less independent functionalities that I didn't find readily available in the usual libraries in the way I like them. Some are present, like command-line option argument parsing, but not in a way that I find convenient to use; others are not found at all.

(If any of this is indeed in the standard library and I just missed it, I'll appreciate a hint.)

The full documentation (what exists of it yet) for this version is at
<https://codeberg.org/jyrgenn/jpylib/src/tag/v$__package_version$/doc/jpylib.md>

[ni@w21.org 2025-03-25]
